@@ -75,8 +75,9 @@ class EpiphanyHandler(deskbar.Handler.Handler):
 		self.watcher.add(self.watched_file)
 	
 	def stop(self):
-		self.watcher.remove(self.watched_file)
-		del self.watcher
+		if hasattr(self, 'watcher'):
+			self.watcher.remove(self.watched_file)
+			del self.watcher
 		
 class EpiphanyBookmarksHandler(EpiphanyHandler):
 	def __init__(self):
@@ -284,7 +285,10 @@ class EpiphanyHistoryParser(xml.sax.ContentHandler):
 		if exists(EPHY_HISTORY_FILE):
 			parser = xml.sax.make_parser()
 			parser.setContentHandler(self)
-			parser.parse(EPHY_HISTORY_FILE)
+			try:
+				parser.parse(EPHY_HISTORY_FILE)
+			except Exception, e:
+				print "Couldn't parse epiphany history file:", e
 
 	
 	def characters(self, chars):
